@@ -3,11 +3,14 @@
 import socket
 
 
-def discover(configuration_endpoint):
+def discover(configuration_endpoint, time_to_timeout=None):
     host, port = configuration_endpoint.split(':')
 
     configs = []
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    if time_to_timeout is not None:
+        sock.settimeout(time_to_timeout)
+
     try:
         sock.connect((host, int(port)))
         sock.sendall('config get cluster\r\n')
